NM_SystemBar = {}

NM_SystemBar.POSITION_DEFAULTS = {x = -20, y = -20}

local MaxFps = 999
local MaxLatency = 999
local HighLatency = 350
local LowLatency = 150

function NM_SystemBar.OnMoveStop()
	NM_SystemBar.SavedVariables.x = NM_SystemBarWin:GetLeft()
	NM_SystemBar.SavedVariables.y = NM_SystemBarWin:GetTop()
end

local function ClockUpdate()
	local Time = ZO_FormatClockTime()
	ClockModuleLabel:SetText(Time)
	local ClockWidth = ClockModuleLabel:GetTextWidth()
	ClockModule:SetWidth(ClockWidth)
end

local function FpsUpdate()
	local Fps = GetFramerate()
	if Fps >= MaxFps then
		Fps = MaxFps
	end
	FpsModuleLabel:SetText("FPS: |cffffff"..zo_round(Fps))
	local FpsWidth = FpsModuleLabel:GetTextWidth()
	FpsModule:SetWidth(FpsWidth)
end

local function LatencyUpdate()
	local Latency = GetLatency()
	if Latency >= MaxLatency then
		Latency = MaxLatency
	end
	if Latency >= HighLatency then
		LatencyModuleIcon:SetTexture("EsoUI/Art/Campaign/campaignbrowser_lowpop.dds")
		LatencyModuleIcon:SetColor(1,0,0,1)
		LatencyModuleLabel:SetColor(1,0,0,1)
	elseif Latency >= LowLatency then
		LatencyModuleIcon:SetTexture("EsoUI/Art/Campaign/campaignbrowser_medpop.dds")
		LatencyModuleIcon:SetColor(1,1,1,1)
		LatencyModuleLabel:SetColor(1,1,1,1)
	elseif Latency < LowLatency then
		LatencyModuleIcon:SetTexture("EsoUI/Art/Campaign/campaignbrowser_hipop.dds")
		LatencyModuleIcon:SetColor(1,1,1,1)
		LatencyModuleLabel:SetColor(1,1,1,1)
	end
	LatencyModuleLabel:SetText(Latency)
	local LatencyWidth = LatencyModuleLabel:GetTextWidth()
	local LatencyIconWidth = LatencyModuleIcon:GetWidth()
	LatencyModuleLabel:SetWidth(LatencyWidth)
	LatencyModule:SetWidth(LatencyWidth+LatencyIconWidth)
end

local function MoneyUpdate(eventCode, newMoney, oldMoney, reason)
	local Gold = GetCurrentMoney()
	GoldModuleLabel:SetText(ZO_CurrencyControl_FormatCurrency(Gold))
	local GoldWidth = GoldModuleLabel:GetTextWidth()
	local GoldIconWidth = GoldModuleIcon:GetWidth()
	GoldModuleLabel:SetWidth(GoldWidth)
	GoldModule:SetWidth(GoldWidth+GoldIconWidth)
end

local function BagUpdate()
	local UsedSlots = GetNumBagUsedSlots(1)
	local BagSize = GetBagSize(1)
	BagModuleLabel:SetText("Inventory Space: |cffffff"..UsedSlots.."/"..BagSize)
end

function NM_SystemBar.ShowTooltip(control)
	local TooltipText
	if control == ClockModule then
		TooltipText = "Local time"
	elseif control == FpsModule then
		TooltipText = "Frames per second. Higher values indicate a smoother experience."
	elseif control == LatencyModule then
		TooltipText = "Your latency to the server in milliseconds. Higher values can result in decreased responsiveness while playing."
	elseif control == GoldModule then
		TooltipText = "Carried Gold"
	elseif control == BagModule then
		TooltipText = "Total inventory space"
	end
	if TooltipText then
		InitializeTooltip(InformationTooltip, control, BOTTOM, 0, 0)
		SetTooltipText(InformationTooltip, TooltipText)
	end
end

function NM_SystemBar.HideTooltip(control)
	ClearTooltip(InformationTooltip)
end

function NM_SystemBar.OnAddOnLoaded(event, name)
	if name == "NM_SystemBar" then
	EVENT_MANAGER:UnregisterForEvent("NM_SystemBar", EVENT_ADD_ON_LOADED)
	NM_SystemBar.Events()
	NM_SystemBar.ControlSystemBar()
	NM_SystemBar.SavedVariables = ZO_SavedVars:New("NM_SystemBar_SavedVariables", 1, nil, NM_SystemBar.POSITION_DEFAULTS)
	NM_SystemBarWin:ClearAnchors()
	NM_SystemBarWin:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, NM_SystemBar.SavedVariables.x, NM_SystemBar.SavedVariables.y)
	end
end

function NM_SystemBar.ControlSystemBar()
	SystemBar = WINDOW_MANAGER:GetControlByName("NM_SystemBarWin", "")
	ClockModule = WINDOW_MANAGER:GetControlByName("NM_SystemBarWinClock", "")
	ClockModuleLabel = WINDOW_MANAGER:GetControlByName("NM_SystemBarWinClockLabel", "")
	FpsModule = WINDOW_MANAGER:GetControlByName("NM_SystemBarWinFps", "")
	FpsModuleLabel = WINDOW_MANAGER:GetControlByName("NM_SystemBarWinFpsLabel", "")
	LatencyModule = WINDOW_MANAGER:GetControlByName("NM_SystemBarWinLatency", "")
	LatencyModuleLabel = WINDOW_MANAGER:GetControlByName("NM_SystemBarWinLatencyLabel", "")
	LatencyModuleIcon = WINDOW_MANAGER:GetControlByName("NM_SystemBarWinLatencyIcon", "")
	GoldModule = WINDOW_MANAGER:GetControlByName("NM_SystemBarWinGold", "")
	GoldModuleLabel = WINDOW_MANAGER:GetControlByName("NM_SystemBarWinGoldLabel", "")
	GoldModuleIcon = WINDOW_MANAGER:GetControlByName("NM_SystemBarWinGoldIcon", "")
	BagModule = WINDOW_MANAGER:GetControlByName("NM_SystemBarWinBags", "")
	BagModuleLabel = WINDOW_MANAGER:GetControlByName("NM_SystemBarWinBagsLabel", "")
	MoneyUpdate(nil,nil,nil,nil)
	BagUpdate()
end

function NM_SystemBar.Events()
	EVENT_MANAGER:RegisterForUpdate("ClockUpdate", 1000, ClockUpdate)
	EVENT_MANAGER:RegisterForUpdate("FpsUpdate", 1000, FpsUpdate)
	EVENT_MANAGER:RegisterForUpdate("LatencyUpdate", 1000, LatencyUpdate)
	EVENT_MANAGER:RegisterForEvent("MoneyUpdate", EVENT_MONEY_UPDATE, MoneyUpdate)
	EVENT_MANAGER:RegisterForEvent("BagUpdate", EVENT_INVENTORY_SINGLE_SLOT_UPDATE, BagUpdate)
end

EVENT_MANAGER:RegisterForEvent("NM_SystemBar", EVENT_ADD_ON_LOADED, NM_SystemBar.OnAddOnLoaded)